@@ -3,7 +3,7 @@ package App::idxdb;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-19'; # DATE
 our $DIST = 'App-idxdb'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,7 +54,7 @@ our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'Import data from IDX and perform queries on them',
+    summary => 'Import data for stocks on the IDX (Indonesian Stock Exchange) and perform queries on them',
 };
 
 my %ownership_fields = (
@@ -633,7 +633,7 @@ sub legend_ownership {
 }
 
 1;
-# ABSTRACT: Import data from IDX and perform queries on them
+# ABSTRACT: Import data for stocks on the IDX (Indonesian Stock Exchange) and perform queries on them
 
 __END__
 
@@ -643,11 +643,11 @@ __END__
 
 =head1 NAME
 
-App::idxdb - Import data from IDX and perform queries on them
+App::idxdb - Import data for stocks on the IDX (Indonesian Stock Exchange) and perform queries on them
 
 =head1 VERSION
 
-This document describes version 0.001 of App::idxdb (from Perl distribution App-idxdb), released on 2021-01-19.
+This document describes version 0.002 of App::idxdb (from Perl distribution App-idxdb), released on 2021-01-19.
 
 =head1 SYNOPSIS
 
